@@ -1,15 +1,14 @@
 package MyApp::Test;
 use strict;
+use warnings;
 use base qw(MyApp);
 use CLITest;
 use constant subcommands => qw(hate Cascading);
-use constant options => (
-    'v|verbose' => 'verbose',
-);
+use constant options => ( 'v|verbose' => 'verbose', );
 
 sub run {
     my $self = shift;
-    cliack($self->{verbose} ? 'v' : '', @_);
+    cliack( $self->{verbose} ? 'v' : '', @_ );
 }
 
 package MyApp::Test::hate;
@@ -18,7 +17,7 @@ use CLITest;
 
 sub run {
     my $self = shift;
-    cliack($self->{verbose} ? 'v' : '', 'hate', @_);
+    cliack( $self->{verbose} ? 'v' : '', 'hate', @_ );
 }
 
 1;
